# frozen_string_literal: true

class Fraction
  attr_reader :nominator, :denominator

  def initialize(nominator, denominator)
    raise '0 can not be a denominator' if denominator.zero?
    if nominator.zero?
      @nominator = 0
      @denominator = denominator
      return
    end
    nok_nom = nominator
    nok_den = denominator
    while nok_nom != nok_den
      nok_den, nok_nom = [nok_nom, nok_den] if nok_nom > nok_den
      nok_den -= nok_nom
    end
    @nominator = nominator / nok_nom
    @denominator = denominator / nok_den
  end

  def sum(other)
    nominator = @nominator * other.denominator + other.nominator * @denominator
    denominator = @denominator * other.denominator
    Fraction.new(nominator, denominator)
  end

  def ==(other)
    return false unless other.is_a?(Fraction)

    nominator == other.nominator &&
      denominator == other.denominator
  end

  def to_s
    "#{nominator} / #{denominator}"
  end
end
