# frozen_string_literal: true

class InteractiveMenu
  def initialize
    @actions = []
  end

  def add(description, action)
    @actions.append(
      description: description,
      action: action
    )
  end

  def run
    puts 'Please select the action to run'
    @actions.each_with_index do |action, index|
      puts "#{index + 1}: #{action[:description]}"
    end
    print 'action> '
    action_number = $stdin.gets.strip.to_i - 1
    raise 'There is no such action with provided number' if action_number.negative? || action_number >= @actions.size

    @actions[action_number][:action].call
  end

  def add_stop_action(description)
    add(description, -> { :stop })
  end

  def infinite_run
    loop do
      break if run == :stop
    rescue StandardError => error
      puts error.message
    end
  end
end
