# frozen_string_literal: true

require 'interactive_menu'

RSpec.describe InteractiveMenu do
  describe '#add' do
  end

  describe '#run' do
    before(:example) do
      @menu = InteractiveMenu.new
      @fake_action = instance_spy('Proc')
      @menu.add('Simplest action', @fake_action)
      allow($stdout).to receive(:puts)
      allow(@menu).to receive(:print)
    end

    it 'should list all actions, ask user to select one and run it' do
      expect($stdin).to receive(:gets).and_return('1')
      expect(@fake_action).to receive(:call)
      @menu.run
    end

    it 'should raise exception when user have selected non-existent action' do
      expect($stdin).to receive(:gets).and_return('500')
      expect { @menu.run }.to raise_error(RuntimeError)
    end
  end

  describe '#infinite_run' do
    it 'should call run intill it returns :stop' do
      menu = InteractiveMenu.new
      expect(menu).to receive(:run).exactly(2).times.and_return(:pass, :stop)
      menu.infinite_run
    end

    it 'shloud print error message when action failed' do
      menu = InteractiveMenu.new
      expect(menu).to receive(:run).and_raise('Error')
      expect(menu).to receive(:run).and_return(:stop)
      expect(menu).to receive(:puts).with('Error')
      menu.infinite_run
    end
  end
end
